@@ -1,5 +1,3 @@
-package org.apache.maven.shared.dependency.analyzer;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.shared.dependency.analyzer;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,6 +16,7 @@ package org.apache.maven.shared.dependency.analyzer;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.shared.dependency.analyzer;
 
 import java.io.IOException;
 import java.net.URL;
@@ -25,18 +24,29 @@ import java.util.Set;
 
 /**
  * Gets the set of classes referenced by a library given either as a jar file or an exploded directory.
- * 
+ *
  * @author <a href="mailto:markhobson@gmail.com">Mark Hobson</a>
- * @version $Id$
  */
-public interface DependencyAnalyzer
-{
-    // fields -----------------------------------------------------------------
+public interface DependencyAnalyzer {
 
-    String ROLE = DependencyAnalyzer.class.getName();
+    /**
+     * <p>analyze.</p>
+     *
+     * @param url            the JAR file or directory to analyze
+     * @return the set of class names referenced by the library
+     * @throws IOException if an error occurs reading a JAR or .class file
+     */
+    default Set<String> analyze(URL url) throws IOException {
+        return analyze(url, new ClassesPatterns());
+    }
 
-    // public methods ---------------------------------------------------------
-
-    Set<String> analyze( URL url )
-        throws IOException;
+    /**
+     * <p>analyze.</p>
+     *
+     * @param url            the JAR file or directory to analyze
+     * @param excludeClasses a class list to exclude
+     * @return the set of class names referenced by the library
+     * @throws IOException if an error occurs reading a JAR or .class file
+     */
+    Set<String> analyze(URL url, ClassesPatterns excludeClasses) throws IOException;
 }
